@@ -40,7 +40,7 @@ Additional utilities for `click <https://click.palletsprojects.com/en/7.x/>`_.
 
 # stdlib
 import sys
-from functools import partial
+from typing import Any, Callable, Dict, Optional, Type, TypeVar, cast
 
 # 3rd party
 import click
@@ -53,7 +53,7 @@ from consolekit.options import _Option
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 __license__: str = "MIT License"
-__version__: str = "1.1.2"
+__version__: str = "1.2.2"
 __email__: str = "dominic@davis-foster.co.uk"
 
 if not bool(getattr(sys, "ps1", sys.flags.interactive)):  # pragma: no cover
@@ -74,22 +74,73 @@ __all__ = [
 		"SuggestionGroup",
 		]
 
-CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"], max_content_width=120)
+_C = TypeVar("_C", bound=click.Command)
+_G = TypeVar("_G", bound=click.Group)
 
-click_command = partial(click.command, context_settings=CONTEXT_SETTINGS)
-"""
-Shortcut to :func:`click.command`, with the ``-h``/``--help`` option enabled and a max width of ``120``.
-"""
+CONTEXT_SETTINGS: Dict[str, Any] = dict(help_option_names=["-h", "--help"], max_content_width=120)
 
-click_group = partial(click.group, context_settings=CONTEXT_SETTINGS, cls=SuggestionGroup)
-"""
-Shortcut to :func:`click.group`, with the ``-h``/``--help`` option enabled and a max width of ``120``.
-"""
 
-option = partial(click.option, cls=_Option)
-"""
-Shortcut to :func:`click.option`, but using :func:`consolekit.input.confirm` when prompting for a boolean flag.
-"""
+def click_command(
+		name: Optional[str] = None,
+		cls: Optional[Type[_C]] = None,
+		**attrs: Any,
+		) -> Callable[[Callable], _C]:
+	r"""
+	Shortcut to :func:`click.command`, with the ``-h``/``--help`` option enabled and a max width of ``120``.
+
+	:param name:
+	:param cls:
+	:type cls: :class:`~typing.Type`\[:class:`~click.Command`\]
+	:default type: :class:`click.Command`
+	:param \*\*attrs: Additional keyword arguments passed to the :class:`~click.Command`.
+
+	:rtype: :class:`~typing.Callable`\[[:class:`~typing.Callable`\], :class:`~click.Command`\]
+	"""
+
+	attrs.setdefault("context_settings", CONTEXT_SETTINGS)
+	return cast(Callable[[Callable], _C], click.command(name, cls=cls, **attrs))
+
+
+def click_group(
+		name: Optional[str] = None,
+		cls: Optional[Type[_G]] = None,
+		**attrs: Any,
+		) -> Callable[[Callable], _G]:
+	r"""
+	Shortcut to :func:`click.group`, with the ``-h``/``--help`` option enabled and a max width of ``120``.
+
+	:param name:
+	:param cls:
+	:type cls: :class:`~typing.Type`\[:class:`~click.Group`\]
+	:default type: :class:`click.Group`
+	:param \*\*attrs: Additional keyword arguments passed to the :class:`~click.Group`.
+
+	:rtype:
+
+	.. latex:clearpage::
+	"""
+
+	if cls is None:
+		cls = SuggestionGroup  # type: ignore
+
+	attrs.setdefault("context_settings", CONTEXT_SETTINGS)
+	return click_command(name, cls=cls, **attrs)  # type: ignore
+
+
+def option(
+		*param_decls: str,
+		**attrs: Any,
+		) -> Callable[[_C], _C]:
+	r"""
+	Shortcut to :func:`click.option`, but using :func:`consolekit.input.confirm` when prompting for a boolean flag.
+
+	:param \*param_decls:
+	:param \*\*attrs: Additional keyword arguments passed to :func:`click.command`.
+	"""
+
+	attrs.setdefault("cls", _Option)
+	return cast(Callable[[_C], _C], click.option(*param_decls, **attrs))
+
 
 # Fixes intersphinx links
 click.Command.__module__ = "click"
