@@ -64,7 +64,7 @@ from typing import Any, Callable, Iterable, List, Optional, Tuple, TypeVar, cast
 
 # 3rd party
 import click
-from click.decorators import _param_memo  # type: ignore
+from click.decorators import _param_memo
 
 # this package
 import consolekit.input
@@ -80,6 +80,7 @@ __all__ = [
 		"flag_option",
 		"auto_default_option",
 		"auto_default_argument",
+		"DescribedArgument",
 		"_A",
 		"_C",
 		]
@@ -118,7 +119,13 @@ def verbose_option(help_text: str = "Show verbose output.") -> Callable[[_C], _C
 	:param help_text: The help text for the option.
 	"""
 
-	return click.option("-v", "--verbose", count=True, help=help_text, type=VerboseVersionCountType())
+	return click.option(  # type: ignore
+		"-v",
+		"--verbose",
+		count=True,
+		help=help_text,
+		type=VerboseVersionCountType(),
+		)
 
 
 def version_option(callback: Callable[[click.Context, click.Option, int], Any]) -> Callable[[_C], _C]:
@@ -149,15 +156,15 @@ def version_option(callback: Callable[[click.Context, click.Option, int], Any])
 
 	"""
 
-	return click.option(
-			"--version",
-			count=True,
-			expose_value=False,
-			is_eager=True,
-			help="Show the version and exit.",
-			type=VerboseVersionCountType(),
-			callback=cast(Callback, callback),
-			)
+	return click.option(  # type: ignore
+		"--version",
+		count=True,
+		expose_value=False,
+		is_eager=True,
+		help="Show the version and exit.",
+		type=VerboseVersionCountType(),
+		callback=cast(Callback, callback),
+		)
 
 
 def colour_option(help_text="Whether to use coloured output.") -> Callable[[_C], _C]:
@@ -215,7 +222,7 @@ def flag_option(*args, default: Optional[bool] = False, **kwargs) -> Callable[[_
 	:param \*\*kwargs: Keyword arguments passed to :func:`click.option`.
 	"""
 
-	return click.option(
+	return click.option(  # type: ignore
 			*args,
 			is_flag=True,
 			default=default,
@@ -258,12 +265,17 @@ def auto_default_option(*param_decls, **attrs) -> Callable[[_C], _C]:
 def _get_default_from_callback_and_set(command: click.Command, param: click.Parameter):
 	if command.callback is not None:
 		# The callback *can* be None, for a no-op
+
+		if param.name is None:  # pragma: no cover
+			raise ValueError("The parameter name cannot be None")
+
 		signature: inspect.Signature = inspect.signature(command.callback)
 
 		param_default = signature.parameters[param.name].default
 
 		if param_default is not inspect.Signature.empty:
 			param.default = param_default
+			param.required = False
 
 
 def auto_default_argument(*param_decls, **attrs) -> Callable[[_C], _C]:
@@ -296,6 +308,8 @@ class MultiValueOption(click.Option):
 	"""
 	Subclass of :class:`click.Option` that behaves like argparse's ``nargs='+'``.
 
+	.. versionadded:: 0.6.0
+
 	:param param_decls: The parameter declarations for this option or argument.
 		This is a list of flags or argument names.
 	:param show_default: Controls whether the default value should be shown on the help page.
@@ -316,8 +330,6 @@ class MultiValueOption(click.Option):
 		and stored on the context, otherwise it is skipped.
 	:param is_eager: Eager values are processed before non eager ones.
 
-	.. versionadded:: 0.6.0
-
 	Example usage:
 
 	.. code-block:: python
@@ -421,7 +433,7 @@ class MultiValueOption(click.Option):
 			if isinstance(value, Iterable) and not isinstance(value, str):
 				return tuple(self.type_cast_value(ctx, v) for v in value)
 			elif value in ("()", str(self.default)) or not value:
-				return self.default
+				return self.default  # type: ignore
 			else:
 				return self.type_cast_value(ctx, value)
 		else:
@@ -440,12 +452,17 @@ class _Option(click.Option):
 		# Calculate the default before prompting anything to be stable.
 		default = self.get_default(ctx)
 
+		prompt_string = cast(str, self.prompt)
+
 		# If this is a prompt for a flag we need to handle this differently.
 		if self.is_bool_flag:
-			return consolekit.input.confirm(self.prompt, default)
+			return consolekit.input.confirm(
+					prompt_string,
+					default,  # type: ignore
+					)
 
 		return consolekit.input.prompt(
-				self.prompt,
+				prompt_string,
 				default=default,
 				type=self.type,
 				hide_input=self.hide_input,
@@ -453,3 +470,30 @@ class _Option(click.Option):
 				confirmation_prompt=self.confirmation_prompt,
 				value_proc=lambda x: self.process_value(ctx, x),
 				)
+
+
+class DescribedArgument(click.Argument):
+	r"""
+	:class:`click.Argument` with an additional keyword argument and attribute giving a short description.
+
+	This is not shown in the help text,
+	but may be useful for manpages or HTML documentation where additional information can be provided.
+
+	.. versionadded:: 1.2.0
+
+	:param description:
+
+	See :class:`click.Argument` and :class:`click.Parameter` for descriptions of the other keyword argu
+	ments.
+
+	.. attribute:: description
+
+		**Type:** |nbsp| |nbsp| |nbsp| |nbsp| :py:obj:`~typing.Optional`\[:py:class:`str`\]
+
+		A short description of the argument.
+	"""
+
+	def __init__(self, *args, description: Optional[str] = None, **kwargs):
+		super().__init__(*args, **kwargs)
+
+		self.description: Optional[str] = description
